"use strict";
/* eslint no-console: off */
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs = __importStar(require("yargs"));
const chalk_1 = __importDefault(require("chalk"));
const types_1 = require("./types");
const _1 = require(".");
const argv = yargs
    .usage('Usage: $0 <graphql-files> [options]')
    .option('schema-path', {
    required: true,
    normalize: true,
    type: 'string',
    describe: 'The path to the JSON file containing a schema instrospection query result',
})
    .option('schema-types-path', {
    required: true,
    normalize: true,
    type: 'string',
    describe: 'The path to output concrete schema types',
})
    .option('watch', {
    required: false,
    default: false,
    type: 'boolean',
    describe: 'Watch the GraphQL files for changes and re-run the generation',
})
    .option('add-typename', {
    required: false,
    default: true,
    type: 'boolean',
    describe: 'Add a __typename field to every object type',
})
    .option('enum-format', {
    required: false,
    type: 'string',
    describe: 'The format in which to generate case names for enum types in the schema',
    choices: [
        types_1.EnumFormat.CamelCase,
        types_1.EnumFormat.PascalCase,
        types_1.EnumFormat.SnakeCase,
        types_1.EnumFormat.ScreamingSnakeCase,
    ],
})
    .help().argv;
const builder = new _1.Builder({
    graphQLFiles: argv._[0],
    schemaPath: argv.schemaPath,
    schemaTypesPath: argv.schemaTypesPath,
    addTypename: argv.addTypename,
    enumFormat: argv.enumFormat,
});
const BUILT = chalk_1.default.inverse.bold.green(' BUILT ');
const ERROR = chalk_1.default.inverse.bold.red(' ERROR ');
builder.on('start', () => {
    console.log();
});
builder.on('schema:start', () => {
    console.log();
});
builder.on('schema:end', () => {
    console.log(`${BUILT} ${argv.schemaTypesPath}`);
});
builder.on('build', ({ documentPath, definitionPath }) => {
    console.log(`${BUILT} ${chalk_1.default.dim(documentPath)} → ${definitionPath}`);
});
builder.on('error', (error) => {
    console.log(`${ERROR} ${error.message}`);
    if (error.stack) {
        console.log(chalk_1.default.dim(error.stack));
    }
    console.log();
    if (!builder.watching) {
        process.exit(1);
    }
});
builder.run({ watch: argv.watch });
